@@ -72,6 +72,8 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     # Create Company years column
     df = devutils.create_company_years_column( df=df )
 
+    df = devutils.create_new_position_flag(df=df, days=90)
+
     # Create new seniorities and the rest go to "other"
     df = devutils.fill_seniority_column( df=df )
 
@@ -103,11 +105,12 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     # Dropping unused variables
     print( model_type )
     cols_to_drop = config['cols_to_drop'][model_type]
-    df = devutils.drop_columns( df=df, columns=cols_to_drop )
+    df = utils.drop_columns( df=df, columns=cols_to_drop )
 
     return df
 
 
+
 def preprocessing_training(df, industry_dictionary, state_dictionary,
                            mx_bv_dictionary, mx_prob_dictionary, config, model_type):
     """[Pre-processing function to prepare the data for training the model and to make predictions]
