@@ -23,6 +23,8 @@ from sklearn.exceptions import DataConversionWarning
 logger = logging.getLogger(__name__)
 
 
+
+
 def set_dataframe_columntypes(df):
     """Manual setting of the datatypes
 
@@ -464,3 +466,13 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
     df = df.replace( {'mx_prob': mx_prob_dict} )
     logger.info(f'{df.mx_prob.value_counts()}')
     return df
+
+
+def create_new_position_flag(df,days):
+    if 'DaysSincePositionStart' in df:
+        logging.info('Days Since position detected, creating flag and deleting the column')
+        df[df['DaysSincePositionStart'].isna()] = 999
+        df['new_position'] = 0
+        df.loc[df['DaysSincePositionStart']< days,'new_position'] = 1
+        df.drop('DaysSincePositionStart',inplace=True)
+    return df
